<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\Sm00008000HabilidadeTarefaService;

class Sm00008000HabilidadeTarefaController extends SMCrud {
    
    protected $dataSourceName = "fct_relachabilipessoa_widget";
    protected $newCode;
    protected $tarefaService;

    public function __construct($crudService, $environment, NewCode $newCode, Sm00008000HabilidadeTarefaService $tarefaService) {
        parent::__construct($crudService, $environment);
        $this->newCode = $newCode;
        $this->tarefaService = $tarefaService;
    }
    
    public function save(Request $request, Response $response) {
        try {
            $nrorg = $this->environment->getNrOrg();
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                $row["NRTAREFAHABILI"] = $this->newCode->getCodeByTableName("FCT_TAREFAHABILI", $nrorg, 1, 10, true);
            }
            unset($row);
            
            parent::save($request, $response);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
    *  A função "recebeOrdenacao" recebe a próxima a ordenação da tarefa 
    *  que está sendo inserida para a habilidade.
    */
    
    public function recebeOrdenacao(Request\Row $request, Response $response) {
    
        $row = $request->getRow();
        
        $cdHabilitServ = $row["CDHABILITSERV"]; 
        
        $ordenacao = $this->tarefaService->recebeOrdenacao($cdHabilitServ);
        
        $dtsOrdenacao = new DataSet('ORDENACAO', $ordenacao);
        
        $response->addDataSet($dtsOrdenacao);
    }   
    
    
    /**
     *  A função "validar" verifica se já existe a ordenação da tarefa 
     *  que está sendo inserida para a habilidade.
     */
     
    public function validar(Request $request, Response $response){
        try {
            $row = $request->getRow();
            $ordenacao = $row["IDORDENACAO"];
            $nrtarefahabili = $row["NRTAREFAHABILI"];
            $cdHabilitServ = $row["CDHABILITSERV"];
            $nrorg = $this->environment->getNrOrg();
            
            $resultado = $this->tarefaService->validar($ordenacao, $nrtarefahabili, $cdHabilitServ, $nrorg);
            
            $response->addDataSet(
                new DataSet(
                    "validar", array(
                        "resultado" => $resultado
                    )
                )
            );
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>